@@ -1,5 +1,5 @@
-mod component;
-mod util;
+pub mod component;
+pub mod util;
 
 #[cfg(test)]
 mod tests {
